@@ -1,9 +1,9 @@
-/*  
+/*
     GNU Gama -- adjustment of geodetic networks
     Copyright (C) 2005  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
-    
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,10 +19,6 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: g3_model_init.cpp,v 1.2 2007/06/26 15:04:10 cepek Exp $
- */
-
 #include <gnu_gama/g3/g3_model.h>
 #include <gnu_gama/g3/g3_cluster.h>
 #include <gnu_gama/outstream.h>
@@ -41,10 +37,10 @@ using   GNU_gama::List;
 typedef GNU_gama::List<Observation*>  ObsList;
 
 
-namespace 
+namespace
 {
-  class Init :  
-    public GNU_gama::ObservationVisitor,
+  class Init :
+    public GNU_gama::BaseVisitor,
     public GNU_gama::Visitor<Height>,
     public GNU_gama::Visitor<Vector>,
     public GNU_gama::Visitor<XYZ>
@@ -68,12 +64,12 @@ namespace
     bool                  updated;
   };
 
-  
+
   void Init::approx_xyz_height()
   {
     obs_in  = &a;
     obs_out = &b;
-   
+
     updated = false;
     ObservationData<Observation>::iterator i=model->obsdata.begin();
     ObservationData<Observation>::iterator e=model->obsdata.end();
@@ -86,7 +82,7 @@ namespace
       {
         obs_in->clear();
         std::swap(obs_in, obs_out);
-        
+
         updated = false;
         for (ObsList::iterator e=obs_in->end(), i=obs_in->begin(); i!=e; i++)
           {
