@@ -1,9 +1,9 @@
-/*  
-    Geodesy and Mapping C++ Library (GNU Gama)
-    Copyright (C) 2004  Ales Cepek <cepek@gnu.org>
+/*
+    GNU Gama -- adjustment of geodetic networks
+    Copyright (C) 2004, 2010  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ Library.
-    
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,10 +19,6 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: gon2deg.h,v 1.2 2007/06/26 15:04:08 cepek Exp $
- */
-
 #include <string>
 
 #ifndef GNU_gama_gons_to_degrees_h___GNU_Gama_gon2deg__gon2deg
@@ -33,12 +29,14 @@ namespace GNU_gama {
 
   // sign 0  conversion without sign
   //      1  sign left-padded
-  //      2  sign right-padded 
+  //      2  sign right-padded
   //      3  signed with leading spaces trimmed
   std::string gon2deg(double gon,  int sign, int prec);
 
   bool        deg2gon(std::string, double &);
 
+  double dms2rad(double);
+  double rad2dms(double);
 }
 
 
