@@ -1,9 +1,9 @@
-/*  
+/*
     GNU Gama -- adjustment of geodetic networks
     Copyright (C) 2003  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
-    
+
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 3 of the License, or
@@ -19,10 +19,6 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: model.h,v 1.5 2008/10/31 18:23:25 cepek Exp $
- */
-
 #ifndef GNU_gama__mathematical_model_h_gnugamamodel___gnu_gama_gmodel___h
 #define GNU_gama__mathematical_model_h_gnugamamodel___gnu_gama_gmodel___h
 
@@ -34,27 +30,27 @@ namespace GNU_gama {
   // Three basic components of mathematical model (of geodetic
   // adjustment) are functional relations (class Model), unknown
   // parameters and constants (class Parameter) and observables (class
-  // Observation). 
+  // Observation).
 
   // Model, Parameter and Observation classes are logically
   // related. To brake the source code dependency we use the 'acyclic
   // visitor' pattern, where Model objects are visiting Observation
   // objects.
 
-  // ObservationVisitor is a completely degenerated class having only
+  // BaseVisitor is a completely degenerated class having only
   // the virtual destructor.
 
 
-  /** ObservationVisitor is a completely degenerated class having only
+  /** BaseVisitor is a completely degenerated class having only
    *  the virtual destructor.
    */
 
-  class ObservationVisitor 
+  class BaseVisitor
   {
-  public: 
-    virtual ~ObservationVisitor() {}
+  public:
+    virtual ~BaseVisitor() {}
   };
-  
+
 
   /** Base observation class.
    */
@@ -72,7 +68,7 @@ namespace GNU_gama {
     virtual ~Observation() {}
 
     virtual int  dimension() const = 0;
-    virtual void accept(ObservationVisitor* visitor) = 0;
+    virtual void accept(BaseVisitor* visitor) = 0;
 
     bool active() const     { return  active_;      }
     bool set_active(bool b) { return (active_ = b); }
@@ -85,35 +81,68 @@ namespace GNU_gama {
 
 
   // .....................................................................
-    
+
 
   /** Abstract visitor class (design pattern 'acyclic visitor')
    */
 
-  template <typename Observation> class Visitor
+  template <typename Element> class Visitor
   {
   public:
     virtual ~Visitor() {}
-    virtual void visit(Observation* observation) = 0;
+    virtual void visit(Element* element) = 0;
   };
-    
+
+
+  /** Helper intermediate template class Accept defines method
+   *  accept() for derived element classes in acyclic visitor pattern.
+   *
+   * Example:
+   *
+   * \code
+   *  //  g3 distance class
+   *
+   *  class Distance : public Accept<Distance, Observation>,
+   *                   public FromTo, public Value {
+   *  public:
+   *
+   *    Distance() {}
+   *    Distance(double d) : Value(d) {}
+   *
+   *    int dimension() const { return 1; }
+   *  };
+   * \endcode
+   */
+
+  template <typename Derived, typename Base>
+    class Accept : public Base {
+  public:
+    void accept(BaseVisitor* visitor)
+    {
+      if (Visitor<Derived>* v = dynamic_cast<Visitor<Derived>*>(visitor))
+        {
+          v->visit(static_cast<Derived*>(this));
+        }
+    }
+  };
+
 
   /** Base template class Model (mathematical model of geodetic
    *  adjustment)
    */
 
-  template <typename Observation> 
+  template <typename Observation>
   class Model
   {
   public:
-    typedef typename 
+    typedef typename
           ObservationData<Observation>::ClusterList   ClusterList;
     typedef Observation                               ObservationType;
     typedef ObservationData<Observation>              ObsData;
 
-    ObsData  obsdata; 
+    ObsData  obsdata;
   };
-  
+
 }
 
 #endif
